<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!-- this style sheet is written by Masaya YAMAGUCHI, 2020-10-11 -->
<xsl:output method="xml" omit-xml-declaration = "yes" />
<xsl:preserve-space elements="*"/>

<xsl:template match="bncDoc">
  <xsl:copy>
    <xsl:attribute name="title">
      <xsl:value-of select="teiHeader/fileDesc/sourceDesc/bibl/title" />
    </xsl:attribute>
    <xsl:attribute name="publisher">
      <xsl:value-of select="teiHeader/fileDesc/sourceDesc/bibl/imprint/publisher" />
    </xsl:attribute>
    <xsl:attribute name="date">
      <xsl:value-of select="normalize-space(teiHeader/fileDesc/sourceDesc/bibl/imprint/date)" />
    </xsl:attribute>
    <xsl:attribute name="author">
      <xsl:call-template name="join">
	<xsl:with-param name="valueList" select="teiHeader/fileDesc/sourceDesc/bibl/author"/>
	<xsl:with-param name="separator" select="','"/>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:apply-templates select="* | text() | @* | processing-instruction()" />
  </xsl:copy>
</xsl:template>


<xsl:template match="w">
  <xsl:copy>
    <xsl:attribute name="h">
      <xsl:value-of select="@hw" />
    </xsl:attribute>
    <xsl:attribute name="c">
      <xsl:value-of select="@c5" />
    </xsl:attribute>
    <xsl:attribute name="p">
      <xsl:value-of select="@pos" />
    </xsl:attribute>
    <xsl:attribute name="t">
      <xsl:choose>
	<xsl:when test="substring(., string-length(.))=' '">
	  <xsl:value-of select="substring(., 1, string-length(.)-1)" />
	</xsl:when>
	<xsl:otherwise>
	  <xsl:value-of select="." />
	</xsl:otherwise>
      </xsl:choose>
    </xsl:attribute>
    <xsl:apply-templates select="* | text() | @* | processing-instruction()" />
    <!--      
	 <xsl:attribute name="t">
	 <xsl:choose>
	 <xsl:when test="substring(., string-length(.))=' '">
	 <xsl:value-of select="substring(., 1, string-length(.)-1)" />
	 </xsl:when>
	 <xsl:otherwise>
	 <xsl:value-of select="." />
	 </xsl:otherwise>
	 </xsl:choose>
	 </xsl:attribute>
	 <xsl:attribute name="ct">
	 <xsl:value-of select="normalize-space(.)" />
	 <xsl:value-of select="translate(normalize-space(.), 'ABCDEFGHIJKLMNOPQRSTUVWXYZ', 'abcdefghijklmnopqrstuvwxyz')" />
	 </xsl:attribute>
    -->    
  </xsl:copy>
</xsl:template>

<xsl:template match="w/@hw">
</xsl:template>
<xsl:template match="w/@c5">
</xsl:template>
<xsl:template match="w/@pos">
</xsl:template>


<xsl:template match="comment()">
<!-- ignore comments -->
</xsl:template>
<xsl:template match="/ | * | text() | @* | processing-instruction()">
<xsl:copy>
<xsl:apply-templates select="* | text() | @* | processing-instruction()"/>
</xsl:copy>
</xsl:template>

<!-- quoted from http://www.codemeit.com/xml/xslt-10-join-a-list-of-elementss-value-with-separator.html -->
<xsl:template name="join" >
  <xsl:param name="valueList" select="''"/>
  <xsl:param name="separator" select="','"/>
  <xsl:for-each select="$valueList">
    <xsl:choose>
      <xsl:when test="position() = 1">
        <xsl:value-of select="."/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="concat($separator, .) "/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:for-each>
</xsl:template>
</xsl:stylesheet>

